macro_rules! sha1_hex {
($($arg:expr),+) => { ... };
}Expand description
A macro to call sha1 hash with variadic arguments and encode to hex string.
macro_rules! sha1_hex {
($($arg:expr),+) => { ... };
}A macro to call sha1 hash with variadic arguments and encode to hex string.